#include <kdialog.h>
#include <klocale.h>

#include "/usr/src/ports/kdewebdev/kdewebdev-16.08.3-1.x86_64/build/kfilereplace/kfilereplaceviewwdg.h"

#include <qvariant.h>
/*
 *  Constructs a KFileReplaceViewWdg as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
KFileReplaceViewWdg::KFileReplaceViewWdg(QWidget* parent, const char* name, Qt::WindowFlags fl)
    : QWidget(parent, name, fl)
{
    setupUi(this);

}

/*
 *  Destroys the object and frees any allocated resources
 */
KFileReplaceViewWdg::~KFileReplaceViewWdg()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void KFileReplaceViewWdg::languageChange()
{
    retranslateUi(this);
}


